# Recipe with ingredient groups

---

- ingredient 0

## Group 1

- ingredient 1
- ingredient 2

### Subgroup 1.1

- ingredient 3
- ingredient 4

##### Subgroup 1.1.1 (Two level deeper headline, still one lever deeper group)

- ingredient 5

#### Subgroup 1.1.2 (One level deeper headline)

- ingredient 6

# Group 2

- ingredient 7
- ingredient 8